@@ -132,7 +132,7 @@ _
 }
 
 our $DATE = '2014-07-03'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 1;
 # ABSTRACT: Create CLI application instance and functions to access it
@@ -149,10 +149,14 @@ Perinci::CmdLine::Server - Create CLI application instance and functions to acce
 
 =head1 VERSION
 
-This document describes version 0.01 of Perinci::CmdLine::Server (from Perl distribution Perinci-CmdLine-Server), released on 2014-07-03.
+This document describes version 0.02 of Perinci::CmdLine::Server (from Perl distribution Perinci-CmdLine-Server), released on 2014-07-03.
 
 =head1 SYNOPSIS
 
+=head2 Running the server
+
+From your L<Perinci::Access::HTTP::Server>-based PSGI application:
+
  use Perinci::CmdLine::Server qw(create_cmdline_server);
  create_cmdline_server(
      name         => 'app1',
@@ -162,13 +166,42 @@ This document describes version 0.01 of Perinci::CmdLine::Server (from Perl dist
      },
  );
 
-Shortcut for simple cases:
+Or, shortcut for simple cases:
 
  use Perinci::CmdLine::Server -app1 => '/Some/Module/some_func';
 
-From command-line:
+Or, for testing using L<peri-htserve>:
 
- % perl -MPerinci::CmdLine::Server=-app1,/Some/Module/some_func ...
+ % peri-htserve --gepok-unix-socket /tmp/app1.sock \
+     -MPerinci::CmdLine::Server=-app1,/Some/Module/some_func \
+     Perinci::CmdLine::Server::app::app1,noload
+
+=head2 Using the server for completion
+
+ # foo-complete
+ #!perl
+ use HTTP::Tiny::UNIX;
+ use JSON;
+
+ my $hres = HTTP::Tiny::UNIX->new->post_form(
+    'http:/tmp/app1.sock//api/Perinci/CmdLine/Server/app/app1/complete_cmdline',
+    {
+        cmdline     => $ENV{COMP_LINE},
+        point       => $ENV{COMP_POINT},
+        '-riap-fmt' => 'json',
+    },
+ );
+ my $rres = decode_json($hres->{content});
+ print $rres->[2];
+
+Activate bash tab completion:
+
+ % chmod +x foo-complete
+ % complete -C foo-complete foo
+ % foo <Tab>
+
+Now foo will be tab-completed using Rinci specification from C<Some::Module>'s
+C<some_func>.
 
 =head1 DESCRIPTION
 
@@ -280,6 +313,8 @@ Return value:
 
 L<Perinci::CmdLine>
 
+L<Perinci::Access::HTTP::Server>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Server>.
